==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/BLANKETORDERLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BLANKETORDERLINEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BLANKETORDERLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLANKETORDERLINEID_Type", propOrder = {
    "blanketorderid",
    "blanketorderlinenum"
})
public class BLANKETORDERLINEID_Type {

    @XmlElement(name = "BLANKETORDERID", required = true)
    protected BLANKETORDERID_Type blanketorderid;
    @XmlElement(name = "BLANKETORDERLINENUM")
    protected long blanketorderlinenum;

    /**
     * Gets the value of the blanketorderid property.
     * 
     * @return
     *     possible object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public BLANKETORDERID_Type getBLANKETORDERID() {
        return blanketorderid;
    }

    /**
     * Sets the value of the blanketorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public void setBLANKETORDERID(BLANKETORDERID_Type value) {
        this.blanketorderid = value;
    }

    /**
     * Gets the value of the blanketorderlinenum property.
     * 
     */
    public long getBLANKETORDERLINENUM() {
        return blanketorderlinenum;
    }

    /**
     * Sets the value of the blanketorderlinenum property.
     * 
     */
    public void setBLANKETORDERLINENUM(long value) {
        this.blanketorderlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/BLANKETORDERLINEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BLANKETORDERLINEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BLANKETORDERLINEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BLANKETORDERLINENUM"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BLANKETORDERLINEID_Type", propOrder = {
    "blanketorderid",
    "blanketorderlinenum"
})
public class BLANKETORDERLINEID_Type {

    @XmlElement(name = "BLANKETORDERID", required = true)
    protected BLANKETORDERID_Type blanketorderid;
    @XmlElement(name = "BLANKETORDERLINENUM")
    protected long blanketorderlinenum;

    /**
     * Obtient la valeur de la propriété blanketorderid.
     * 
     * @return
     *     possible object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public BLANKETORDERID_Type getBLANKETORDERID() {
        return blanketorderid;
    }

    /**
     * Définit la valeur de la propriété blanketorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link BLANKETORDERID_Type }
     *     
     */
    public void setBLANKETORDERID(BLANKETORDERID_Type value) {
        this.blanketorderid = value;
    }

    /**
     * Obtient la valeur de la propriété blanketorderlinenum.
     * 
     */
    public long getBLANKETORDERLINENUM() {
        return blanketorderlinenum;
    }

    /**
     * Définit la valeur de la propriété blanketorderlinenum.
     * 
     */
    public void setBLANKETORDERLINENUM(long value) {
        this.blanketorderlinenum = value;
    }

}
